﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using SweetBunsContracts.Extensions;
using SweetBunsContracts.Infrastructure;
using SweetBunsContracts.Exceptions;

namespace SweetBunsContracts.DataModels;

public class SaleDataModel(string id, string employeeId, double sum, bool isCanceled) : IValidation
{
    public string Id { get; private set; } = id;

    public string EmployeeId { get; private set; } = employeeId;

    public DateTime SaleDate { get; private set; } = DateTime.UtcNow;

    public double Sum { get; private set; } = sum;
    public bool IsCanceled { get; private set; } = isCanceled;

    public void Validate()
    {
        if (Id.IsEmpty())
            throw new ValidationException("Field Id is empty");

        if (!Id.IsGuid())
            throw new ValidationException("The value in the field Id is not a unique identifier");

        if (EmployeeId.IsEmpty())
            throw new ValidationException("Field EmployeeId is empty");

        if (!EmployeeId.IsGuid())
            throw new ValidationException("The value in the field EmployeeId is not a unique identifier");

        if (Sum <= 0)
            throw new ValidationException("Field Sum is less than or equal to 0");
    }
}
